@@ -256,32 +256,25 @@ par(Mypar)
 
 ## ----fig.align="center",out.width="100%",message=FALSE,dpi=200,eval=TRUE,fig.height=1----
 
-#Prepare layout for 3 sub-plots
-Mypar<-par(mfrow=c(1,3),mai=c(0,0.01,0.2,0.01))
+#Prepare layout for 2 sub-plots
+Mypar<-par(mfrow=c(1,2),mai=c(0,0.01,0.2,0.01))
 
 #Example 1: Simple grid, using automatic colors
 MyGrid=create_PolyGrids(Input=GridData,dlon=2,dlat=1)
 plot(MyGrid,col=MyGrid$Col_Catch_sum,main='Example 1',cex.main=0.5,lwd=0.1)
 box()
 
-#Example 2: Equal area grid, using automatic colors
-MyGrid=create_PolyGrids(Input=GridData,Area=10000)
-plot(MyGrid,col=MyGrid$Col_Catch_sum,main='Example 2',cex.main=0.5,lwd=0.1)
+#Example 2: Same grid, colored by the area of each cell. This function offers an equal-area gridding
+# option if required (see ?create_PolyGrids).
+plot(MyGrid,col=MyGrid$Col_AreaKm2,main='Example 2',cex.main=0.5,lwd=0.1)
 box()
 
-#Example 3: Equal area grid, using custom cuts and colors
-MyGrid=create_PolyGrids(Input=GridData,Area=10000,cuts=c(0,50,100,500,2000,3500),cols=c('blue','red'))
-plot(MyGrid,col=MyGrid$Col_Catch_sum,main='Example 3',cex.main=0.5,lwd=0.1)
-box()
 par(Mypar)
 
 ## ----fig.align="center",out.width="100%",message=FALSE,dpi=200,eval=TRUE,fig.height=3----
 
 #Prepare layout for 2 sub-plots
-Mypar<-par(mfrow=c(2,1),mai=c(0.2,0.05,0.1,0.1))
-
-#Step 1: Generate your grid
-MyGrid=create_PolyGrids(Input=GridData,Area=10000)
+Mypar<-par(mfrow=c(2,1),mai=c(0.2,0.05,0.1,0.15))
 
 #Step 2: Inspect your gridded data (e.g. sum of Catch) to determine whether irregular cuts are required
 hist(MyGrid$Catch_sum,100,cex=0.5,main='Frequency distribution of data',
@@ -291,7 +284,7 @@ text(seq(0,2500,by=500),-1.5,seq(0,2500,by=500),cex=0.5,xpd=TRUE)
 
 #In this case (heterogeneously distributed data) irregular cuts would be preferable
 #Such as:
-MyCuts=c(0,50,100,500,2000,2500)
+MyCuts=c(0,50,100,500,2000,3500)
 abline(v=MyCuts,col='green',lwd=0.1,lty=2) #Add classes to histogram as green dashed lines
 
 #Step 3: Generate colors according to the desired classes (MyCuts)
@@ -301,9 +294,8 @@ Gridcol=add_col(MyGrid$Catch_sum,cuts=MyCuts,cols=c('yellow','purple'))
 #Use the colors generated by add_col
 plot(MyGrid,col=Gridcol$varcol,lwd=0.1) 
 #Add color scale using cuts and cols generated by add_col
-add_Cscale(title='Sum of Catch (t)',cuts=Gridcol$cuts,cols=Gridcol$cols,width=26,
-     fontsize=0.35,lwd=0.5) 
-box()
+add_Cscale(title='Sum of Catch',cuts=Gridcol$cuts,cols=Gridcol$cols,width=17,
+     fontsize=0.35,lwd=0.5,offset=-400) 
 par(Mypar)
 
 ## ----eval=FALSE---------------------------------------------------------------
@@ -347,53 +339,6 @@ plot(MyPoly,add=TRUE,border='red',lwd=1)
 plot(MyStations,add=TRUE,col='orange',cex=0.5)
 par(Mypar)
 
-## ----fig.align="center",out.width="100%",message=FALSE,dpi=200,eval=TRUE------
-
-#Create polygon as shown above
-MyPolys=create_Polys(Input=PolyData,Densify=TRUE)
-MyPoly=MyPolys[MyPolys$ID=='one',]
-
-#optional: crop your bathymetry raster to match the extent of your polygon
-BathyCroped=raster::crop(SmallBathy,MyPoly)
-
-MyStations=create_Stations(Poly=MyPoly,Bathy=BathyCroped,
-                           Depths=c(-2000,-1500,-1000,-550),N=c(20,15,10),dist=10)
-#Set the figure margins as c(bottom, left, top, right)
-Mypar<-par(mai=c(0,0,0,0))
-
-#add custom colors to the bathymetry to indicate the strata of interest
-MyCols=add_col(var=c(-10000,10000),cuts=c(-2000,-1500,-1000,-550),cols=c('blue','cyan'))
-plot(BathyCroped,breaks=MyCols$cuts,col=MyCols$cols,legend=FALSE,axes=FALSE,box=FALSE)
-add_Cscale(height=90,fontsize=0.5,width=25,lwd=0.5,offset=0,cuts=MyCols$cuts,cols=MyCols$cols)
-plot(MyPoly,add=TRUE,border='red',lwd=1)
-plot(MyStations[MyStations$Stratum=='1000-550',],pch=21,bg='yellow',add=TRUE,cex=0.75,lwd=0.1)
-plot(MyStations[MyStations$Stratum=='1500-1000',],pch=21,bg='orange',add=TRUE,cex=0.75,lwd=0.1)
-plot(MyStations[MyStations$Stratum=='2000-1500',],pch=21,bg='red',add=TRUE,cex=0.75,lwd=0.1)
-par(Mypar)
-
-## ----fig.align="center",out.width="100%",message=FALSE,dpi=200,eval=TRUE------
-
-#Create polygon as shown above
-MyPolys=create_Polys(Input=PolyData,Densify=TRUE)
-MyPoly=MyPolys[MyPolys$ID=='one',]
-
-#optional: crop your bathymetry raster to match the extent of your polygon
-BathyCroped=raster::crop(SmallBathy,MyPoly)
-
-MyStations=create_Stations(Poly=MyPoly,Bathy=BathyCroped,Depths=c(-2000,-1500,-1000,-550),Nauto=30,dist=10)
-#Set the figure margins as c(bottom, left, top, right)
-Mypar<-par(mai=c(0,0,0,0))
-
-#add custom colors to the bathymetry to indicate the strata of interest
-MyCols=add_col(var=c(-10000,10000),cuts=c(-2000,-1500,-1000,-550),cols=c('blue','cyan'))
-plot(BathyCroped,breaks=MyCols$cuts,col=MyCols$cols,legend=FALSE,axes=FALSE,box=FALSE)
-add_Cscale(height=90,fontsize=0.5,width=25,lwd=0.5,offset=0,cuts=MyCols$cuts,cols=MyCols$cols)
-plot(MyPoly,add=TRUE,border='red',lwd=1)
-plot(MyStations[MyStations$Stratum=='1000-550',],pch=21,bg='yellow',add=TRUE,cex=0.75,lwd=0.1)
-plot(MyStations[MyStations$Stratum=='1500-1000',],pch=21,bg='orange',add=TRUE,cex=0.75,lwd=0.1)
-plot(MyStations[MyStations$Stratum=='2000-1500',],pch=21,bg='red',add=TRUE,cex=0.75,lwd=0.1)
-par(Mypar)
-
 ## ----eval=FALSE---------------------------------------------------------------
 #  ?load_ASDs
 
@@ -576,31 +521,6 @@ add_Cscale(title='Number of fishes',
 box()
 par(Mypar)
 
-## ----fig.align="center",out.width="100%",message=FALSE,dpi=200,eval=TRUE------
-
-#Adding colors to a grid with custom cuts (see also the last example in section 2.1.)
-
-#Step 1: Generate your grid
-MyGrid=create_PolyGrids(Input=GridData,Area=10000)
-
-#Step 2: Inspect your gridded data (e.g. hist(MyGrid$Catch_sum,100))
-#to determine whether irregular cuts are required.
-#In this case (heterogeneously distributed data) irregular cuts 
-#would be preferable, such as:
-MyCuts=c(0,50,100,500,2000,2500)
-
-#Step 3: Generate colors according to the desired classes (MyCuts)
-Gridcol=add_col(MyGrid$Catch_sum,cuts=MyCuts,cols=c('blue','white','red'))
-
-#Step 4: Plot result and add color scale
-Mypar<-par(mai=c(0,0,0,0.8)) #set plot margins as c(bottom, left, top, right)
-#Use the colors generated by add_col
-plot(MyGrid,col=Gridcol$varcol,lwd=0.1) 
-#Add color scale using cuts and cols generated by add_col
-add_Cscale(title='Sum of Catch (t)',cuts=Gridcol$cuts,cols=Gridcol$cols,width=26,
-     fontsize=0.35,lwd=0.5) 
-par(Mypar)
-
 ## ----eval=FALSE---------------------------------------------------------------
 #  ?legend
 
